<?php
/*
Plugin Name: Fancy Text Widget
Plugin URI: http://fancy-text-widget.webfactoryltd.com
Description: Fancy, colorful, customizable text widget.
Author: Web factory Ltd
Version: 1.0
Author URI: http://www.webfactoryltd.com/
*/

if (!function_exists('add_action')) {
  die('Please don\'t open this file directly!');
}

class wf_ftw {
  // add hooks and filters
  function init() {
    if (is_admin()) {
      add_action('admin_head', array('wf_ftw', 'admin_head'));
    } else {
      add_action('wp_footer', array('wf_ftw', 'wp_footer'));
    }
  } // init

  // initialize widgets
  function widgets_init() {
    register_widget('fancy_text');
  } // widgets init

  // inject JS/CSS in admin head
  function admin_head() {
    $uri = $_SERVER['REQUEST_URI'];

    if (strpos($uri, 'widgets.php') !== false) {
      $colorpicker_css = plugins_url('/css/ftw-colorpicker.css', __FILE__);
      $colorpicker_js = plugins_url('/js/ftw-colorpicker.js', __FILE__);

      echo '<script type="text/javascript" src="' . $colorpicker_js . '"></script>' . "\n";
      echo '<link rel="stylesheet" href="' . $colorpicker_css . '" type="text/css" media="all" />' . "\n";
    } // if widgets.php
  } // admin_head

  // inject CSS in theme footer
  function wp_footer() {
      global $ftw_do_footer, $ftw_fonts;

      $fonts['ftw-font-waiting-for-the-sunrise'] = 'Waiting+for+the+Sunrise';
      $fonts['ftw-font-the-girl-next-door'] = 'The+Girl+Next+Door';
      $fonts['ftw-font-sue-ellen-francisco'] = 'Sue+Ellen+Francisco';
      $fonts['ftw-font-annie-use-your-telescope'] = 'Annie+Use+Your+Telescope';
      $fonts['ftw-font-indie-flower'] = 'Indie+Flower';
      $fonts['ftw-font-architects-daughter'] = 'Architects+Daughter';
      $fonts['ftw-font-just-me-again-down-here'] = 'Just+Me+Again+Down+Here';
      $fonts['ftw-font-just-another-hand'] = 'Just+Another+Hand';
      $fonts['ftw-font-covered-by-your-grace'] = 'Covered+By+Your+Grace';
      $fonts['ftw-font-schoolbell'] = 'Schoolbell';

      if ($ftw_do_footer == true) {
        $css = plugins_url('/css/ftw.css', __FILE__);
        echo '<style type="text/css">@import url("' . $css . '");</style>' . "\n";

        if ($ftw_fonts) {
          foreach ($ftw_fonts as $font) {
            $font = 'http://fonts.googleapis.com/css?family=' . $fonts[$font];
            echo '<style type="text/css">@import url("' . $font . '");</style>' . "\n";
          }
        } // if fonts
      }
  } // wp_footer

  // helper function for creating dropdowns
  function create_select_options($options, $selected = null, $output = true) {
    $out = "\n";

    foreach ($options as $tmp) {
      if ($selected == $tmp['val']) {
        $out .= "<option selected=\"selected\" value=\"{$tmp['val']}\">{$tmp['label']}&nbsp;</option>\n";
      } else {
        $out .= "<option value=\"{$tmp['val']}\">{$tmp['label']}&nbsp;</option>\n";
      }
    } // foreach

    if ($output) {
      echo $out;
    } else {
      return $out;
    }
  } // create_select_options
} // class wf_ftw

// widget class
class fancy_text extends WP_Widget {
  // constructor method
  function fancy_text() {
    $widget_ops = array('classname' => 'fancy_text', 'description' => 'Fancy, colorful arbitrary text or HTML');
    $control_ops = array('width' => 400, 'height' => 350);
    $this->WP_Widget('fancy_text', 'Fancy Text', $widget_ops, $control_ops);
  } // fancy_text

  // widget HTML generator
  function widget($args, $instance) {
    global $ftw_do_footer, $ftw_fonts;

    extract($args);
    extract($instance);

    $ftw_do_footer = true;
    $ftw_fonts[] = $font;

    $title = apply_filters('widget_title', empty($instance['title']) ? '' : $instance['title'], $instance, $this->id_base);
    $text = do_shortcode($instance['text']);
    if ($instance['filter']) {
      $text = wpautop($text);
    }

    if ($font_color) {
      $font_color = ' color:' . $font_color . ' !important;';
    }

    echo $before_widget;
    echo '<div class="ftw-container">';
    echo '<div class="ftw-body ' . $background . ' ' . $font . '" style="background-color: ' . $instance['color'] . ' !important;' . $font_color . '"><div class="ftw-spacing">';
    if (!empty($title)) {
      echo '<strong>' . $title . '</strong><br />';
    }
    echo $text . '</div></div>';
    echo '<div class="ftw-footer">';
    if ($corners == 'both') {
      echo '<div class="ftw-footer-left"></div>';
      echo '<div class="ftw-footer-right"></div>';
    } elseif ($corners == 'left') {
      echo '<div class="ftw-footer-left"></div>';
    } elseif ($corners == 'right') {
      echo '<div class="ftw-footer-right"></div>';
    }
    echo '</div>';
    echo '<div class="' . $icon . ' ' . $icon_position . '"></div>';
    echo '</div>';
    echo $after_widget;
  } // widget

  // update widget settings
  function update($new_instance, $old_instance) {
    $instance = $new_instance;

    $instance['title'] = strip_tags($new_instance['title']);
    if (current_user_can('unfiltered_html')) {
      $instance['text'] = $new_instance['text'];
    } else {
      $instance['text'] = stripslashes(wp_filter_post_kses(addslashes($new_instance['text'])));
    }
    $instance['filter'] = isset($new_instance['filter']);
    $instance['color'] = substr($instance['color'], 0, 7);

    return $instance;
  } // update

  // widget customization form
  function form($instance) {
    $instance = wp_parse_args((array) $instance, array('title' => 'Widget title',
                                                       'text' => 'You are reading text inside a fancy text widget. There\'s no real purpose to it. It\'s just <strong>fancy</strong>!',
                                                       'filter' => 0,
                                                       'background' => 'ftw-body-horizontal-vertical-lines-paper',
                                                       'icon' => 'ftw-graphics-tape-2',
                                                       'icon_position' => 'ftw-graphics-right',
                                                       'font' => 'ftw-font-schoolbell',
                                                       'corners' => 'both',
                                                       'font-color' => '',
                                                       'color' => '#57bdcf'));
    $title = strip_tags($instance['title']);

    $backgrounds[] = array('val' => '', 'label' => 'Plain');
    $backgrounds[] = array('val' => 'ftw-body-crumbled-paper-1', 'label' => 'Crumbled paper, less');
    $backgrounds[] = array('val' => 'ftw-body-crumbled-paper-2', 'label' => 'Crumbled paper, more');
    $backgrounds[] = array('val' => 'ftw-body-sand-paper-1', 'label' => 'Sand paper, fine');
    $backgrounds[] = array('val' => 'ftw-body-sand-paper-2', 'label' => 'Sand paper, more grainy');
    $backgrounds[] = array('val' => 'ftw-body-horizontal-lines-paper', 'label' => 'Paper with horizontal lines');
    $backgrounds[] = array('val' => 'ftw-body-horizontal-vertical-lines-paper', 'label' => 'Paper with horizontal and vertical lines');

    $icons[] = array('val' => '', 'label' => 'None');
    $icons[] = array('val' => 'ftw-graphics-tape-1', 'label' => 'Sticky tape vertical');
    $icons[] = array('val' => 'ftw-graphics-tape-2', 'label' => 'Stick type diagonal');
    $icons[] = array('val' => 'ftw-graphics-paperclip', 'label' => 'Paper clip');
    $icons[] = array('val' => 'ftw-graphics-paperclip-oldschool', 'label' => 'Old school paper clip');
    $icons[] = array('val' => 'ftw-graphics-pinup', 'label' => 'Safety pin');
    $icons[] = array('val' => 'ftw-graphics-pin-blue', 'label' => 'Blue pin');
    $icons[] = array('val' => 'ftw-graphics-pin-red', 'label' => 'Red pin');
    $icons[] = array('val' => 'ftw-graphics-pin-white', 'label' => 'White pin');
    $icons[] = array('val' => 'ftw-graphics-pin-green', 'label' => 'Green pin');
    $icons[] = array('val' => 'ftw-graphics-pin-black', 'label' => 'Black pin');

    $icons_position[] = array('val' => 'ftw-graphics-left', 'label' => 'Top left');
    $icons_position[] = array('val' => 'ftw-graphics-right', 'label' => 'Top right');

    $corners[] = array('val' => '', 'label' => 'Both straight');
    $corners[] = array('val' => 'both', 'label' => 'Both folded');
    $corners[] = array('val' => 'left', 'label' => 'Left folded');
    $corners[] = array('val' => 'right', 'label' => 'Right folded');

    $fonts[] = array('val' => '', 'label' => 'Default, theme defined');
    $fonts[] = array('val' => 'ftw-font-the-girl-next-door', 'label' => 'The Girl Next Door');
    $fonts[] = array('val' => 'ftw-font-sue-ellen-francisco', 'label' => 'Sue Ellen Francisco');
    $fonts[] = array('val' => 'ftw-font-annie-use-your-telescope', 'label' => 'Annie Use Your Telescope');
    $fonts[] = array('val' => 'ftw-font-waiting-for-the-sunrise', 'label' => 'Waiting for the Sunrise');
    $fonts[] = array('val' => 'ftw-font-indie-flower', 'label' => 'Indie Flower');
    $fonts[] = array('val' => 'ftw-font-architects-daughter', 'label' => 'Architects Daughter');
    $fonts[] = array('val' => 'ftw-font-just-me-again-down-here', 'label' => 'Just Me Again Down Here');
    $fonts[] = array('val' => 'ftw-font-just-another-hand', 'label' => 'Just Another Hand');
    $fonts[] = array('val' => 'ftw-font-covered-by-your-grace', 'label' => 'Covered By Your Grace');
    $fonts[] = array('val' => 'ftw-font-schoolbell', 'label' => 'School bell');

    echo '<script type="text/javascript">' . "\n";
    echo "jQuery('#" . $this->get_field_id('color') . "').css('background-color', jQuery('#" . $this->get_field_id('color') . "').val()); ";
    echo "jQuery('#" . $this->get_field_id('font_color') . "').css('background-color', jQuery('#" . $this->get_field_id('font_color') . "').val()); ";
    echo "ftw_colorpicker('" . $this->get_field_id('color') . "');\n";
    echo "ftw_colorpicker('" . $this->get_field_id('font_color') . "');\n";
    echo '</script>';

    echo '<p><label for="' . $this->get_field_id('title') . '">Title</label>';
    echo '<input class="widefat" id="' . $this->get_field_id('title') . '" name="' . $this->get_field_name('title') . '" type="text" value="'. esc_attr($title) . '" /></p>';

    echo '<p><textarea class="widefat" rows="16" cols="20" id="' . $this->get_field_id('text') . '" name="' . $this->get_field_name('text') . '">' . $instance['text'] . '</textarea></p>';

    echo '<p><label for="' . $this->get_field_id('filter') . '">Automatically add paragraphs to text</label>&nbsp;&nbsp;';
    echo '<input id="' . $this->get_field_id('filter') . '" name="' . $this->get_field_name('filter') . '" type="checkbox" ' . checked(isset($instance['filter'])? $instance['filter']: 0, true, false) . ' /></p>';

    echo '<p><label for="' . $this->get_field_id('background') . '">Background</label>&nbsp;&nbsp;';
    echo '<select name="' . $this->get_field_name('background') . '" id="' . $this->get_field_id('background') . '">';
    wf_ftw::create_select_options($backgrounds, $instance['background'], true);
    echo '</select></p>';

    echo '<p><label for="' . $this->get_field_id('color') . '">Background color</label>&nbsp;&nbsp;';
    echo '<input onclick="ftw_bind_fix(\'' . $this->get_field_id('color') . '\');" class="medium-text ftw-color" id="' . $this->get_field_id('color') . '" name="' . $this->get_field_name('color') . '" type="text" value="'. $instance['color'] . '" /></p>';

    echo '<p><label for="' . $this->get_field_id('font_color') . '">Font color</label>&nbsp;&nbsp;';
    echo '<input onclick="ftw_bind_fix(\'' . $this->get_field_id('font_color') . '\');" class="medium-text ftw-color" id="' . $this->get_field_id('font_color') . '" name="' . $this->get_field_name('font_color') . '" type="text" value="'. $instance['font_color'] . '" />';
    echo '&nbsp;&nbsp;<input type="button" class="button-secondary" value="Default theme color" onclick="jQuery(\'#' . $this->get_field_id('font_color') . ' \').val(\'\').css(\'background-color\', \'white\');" /></p>';

    echo '<p><label for="' . $this->get_field_id('font') . '">Font</label>&nbsp;&nbsp;';
    echo '<select name="' . $this->get_field_name('font') . '" id="' . $this->get_field_id('font') . '">';
    wf_ftw::create_select_options($fonts, $instance['font'], true);
    echo '</select></p>';

    echo '<p><label for="' . $this->get_field_id('icon') . '">Icon</label>&nbsp;&nbsp;';
    echo '<select name="' . $this->get_field_name('icon') . '" id="' . $this->get_field_id('icon') . '">';
    wf_ftw::create_select_options($icons, $instance['icon'], true);
    echo '</select></p>';

    echo '<p><label for="' . $this->get_field_id('icon_position') . '">Icon position</label>&nbsp;&nbsp;';
    echo '<select name="' . $this->get_field_name('icon_position') . '" id="' . $this->get_field_id('icon_position') . '">';
    wf_ftw::create_select_options($icons_position, $instance['icon_position'], true);
    echo '</select></p>';

    echo '<p><label for="' . $this->get_field_id('corners') . '">Corners</label>&nbsp;&nbsp;';
    echo '<select name="' . $this->get_field_name('corners') . '" id="' . $this->get_field_id('corners') . '">';
    wf_ftw::create_select_options($corners, $instance['corners'], true);
    echo '</select></p>';
  } // form
} // fancy_text

// hook everything up
add_action('init',         array('wf_ftw', 'init'));
add_action('widgets_init', array('wf_ftw', 'widgets_init'));
?>